@@ -191,7 +191,7 @@ class FileList(CT.CustomTreeCtrl):
                 if filterValue and len(filterValue) > 0:
                     if fileName.lower().find(filterValue.lower()) == -1:
                         continue
-                if fileName.endswith(".py") or fileName.endswith(".ini") or fileName.endswith(".txt"):
+                if fileName.endswith(".py") or fileName.endswith(".ini") or fileName.endswith(".txt") or fileName.endswith(".fer"):
                     fileItem = self.AppendItem(parent, fileName, ct_type=1)
                     self.SetPyData(fileItem, None)
                     self.SetItemImage(fileItem, 28, CT.TreeItemIcon_Normal)
@@ -295,7 +295,6 @@ class FileList(CT.CustomTreeCtrl):
 
         elif _itemText.endswith(".txt"):
             menu = wx.Menu()
-            # menu.AppendSeparator()
 
             if len(self.checkedItemPath) > 0:
                 item_run_select = menu.Append(wx.ID_ANY,
@@ -320,6 +319,39 @@ class FileList(CT.CustomTreeCtrl):
             menu.Destroy()
             return
 
+        elif _itemText.endswith(".fer"):
+            menu = wx.Menu()
+            # menu.AppendSeparator()
+            item_run = menu.Append(wx.ID_ANY, 'Crypt Run "{}"'.format(self.GetItemText(self.current)))
+
+            item_stop = menu.Append(wx.ID_ANY, "Stop")
+            menu.AppendSeparator()
+
+            if len(self.checkedItemPath) > 0:
+                item_run_select = menu.Append(wx.ID_ANY,
+                                              'Run selected files')
+                item_save_select = menu.Append(wx.ID_ANY,
+                                               'Save selected files')
+
+                self.Bind(wx.EVT_MENU, self.OnItemRunSelect, item_run_select)
+                self.Bind(wx.EVT_MENU, self.OnItemSaveSelect, item_save_select)
+            menu.AppendSeparator()
+
+            item_rename = menu.Append(wx.ID_ANY, "Rename...")
+            item_delete = menu.Append(wx.ID_ANY, "Delete...")
+
+            if item == self.GetRootItem():
+                item_delete.Enable(False)
+
+            self.Bind(wx.EVT_MENU, self.OnItemRun, item_run)
+            self.Bind(wx.EVT_MENU, self.OnItemStop, item_stop)
+            self.Bind(wx.EVT_MENU, self.OnItemRename, item_rename)
+            self.Bind(wx.EVT_MENU, self.OnItemDelete, item_delete)
+
+            self.PopupMenu(menu)
+            menu.Destroy()
+            return
+
         elif _itemText.endswith(".ini"):
             menu = wx.Menu()
             # menu.AppendSeparator()
